@@ -11,9 +11,9 @@
 #   We have chosen to make it as simple to understand as possible. There are comments
 #   and notes written throughout to help the reader understand more.
 #
+from collections import OrderedDict
 from typing import Optional, Dict, List, Union
 import json
-from collections import OrderedDict
 
 import requests
 
@@ -93,10 +93,12 @@ class Privileges:
     CAN_INVOKE_CUSTOM_R_ANALYSIS = 'RANALYSIS'
     CANNOT_CREATE_OR_DELETE_PINBOARDS = 'DISABLE_PINBOARD_CREATION'
 
+
 class PermissionTypes:
     EFFECTIVE = 'EFFECTIVE'
     DEFINED = 'DEFINED'
 
+
 #
 # Method Naming Conventions: The methods are meant to be named after the endpoint naming. A '/' is replaced by an '_'
 # such that 'user/list' becomes 'user_list()'.
@@ -488,7 +490,7 @@ class TSRestApiV1:
 
         post_data = {
             'name': group_name,
-            'display_name': display_name,
+            'displayname': display_name,
             'grouptype': group_type,
             'visibility': visibility
         }
@@ -638,7 +640,6 @@ class TSRestApiV1:
     def get_sheets_from_metadata_details(metadata_details_response):
         return metadata_details_response['storables'][0]['reportContent']['sheets']
 
-
     # Tag Methods
 
     # Format for assign tags is that the object_guids List can take any object type, but then you must
@@ -801,7 +802,6 @@ class TSRestApiV1:
     @staticmethod
     def raise_tml_errors(response: requests.Response) -> Dict:
         if len(response.content) == 0:
-            #print(response.status_code)
             raise Exception('No response returned at all with status code {}'.format(response.status_code))
         else:
             j = response.json()
@@ -825,7 +825,6 @@ class TSRestApiV1:
                     else:
                         return response.json()
 
-
             else:
                 return response.json()
 
@@ -1096,7 +1095,6 @@ class TSRestApiV1:
         response.raise_for_status()
         return response.json()
 
-
     #
     # SESSION Methods
     #
@@ -1172,7 +1170,7 @@ class TSRestApiV1:
         post_data = {
             'name': username,
             'password': password,
-            'display_name': display_name,
+            'displayname': display_name,
             'usertype': user_type,
             'visibility': visibility
         }
@@ -1402,12 +1400,40 @@ class TSRestApiV1:
         response.raise_for_status()
         # Returns a 204 when complete
 
+    def connection_detail(self, connection_guid: str, sort: str = 'MODIFIED', sort_ascending: bool = True,
+                          filter: Optional[str] = None, tagname: Optional[List[str]] = None, show_hidden: bool = False):
+        endpoint = 'connection/detail/{}'.format(connection_guid)
+
+        url = self.non_public_base_url + endpoint
+        url_params = {
+                     'sort': sort,
+                     'sort_ascending': str(sort_ascending).lower(),
+                     'show_hidden': str(show_hidden).lower()
+                     }
+        if filter is not None:
+            url_params['pattern'] = filter
+        if tagname is not None:
+            url_params['tagname'] = json.dumps(tagname)
+
+        response = self.session.get(url=url, params=url_params)
+        response.raise_for_status()
+        return response.json()
+
     def connection_fetch_connection(self, connection_guid, config_json_string, include_columns=False, authentication_type='SERVICE_ACCOUNT'):
         endpoint = 'connection/fetchConnection'
 
         url = self.non_public_base_url + endpoint
-        # Example of a config_json, which may vary per connection (use
-        config_json_example = '{"password":"","role":"SE_ROLE","warehouse":"SE_DEMO_WH","accountName":"thoughtspot_partner","user":"se_demo"}'
+        # Example of a config_json, which may vary per connection
+        #
+        # config_json_string_example = '''
+        #       {  "password": "",
+        #          "role": "SE_ROLE",
+        #          "warehouse": "SE_DEMO_WH",
+        #          "accountName": "thoughtspot_partner",
+        #          "user": "se_demo"
+        #       }
+        # '''
+        #
         post_data = {'id': connection_guid,
                      'config': config_json_string,
                      'includeColumns': str(include_columns).lower(),
@@ -1428,8 +1454,17 @@ class TSRestApiV1:
                   "schemaName": schema_name,
                   "tableName": table_name
                   }]
-        # Example of a config_json, which may vary per connection (use
-        config_json_example = '{"password":"","role":"SE_ROLE","warehouse":"SE_DEMO_WH","accountName":"thoughtspot_partner","user":"se_demo"}'
+        # Example of a config_json, which may vary per connection
+        #
+        # config_json_string_example = '''
+        #       {  "password": "",
+        #          "role": "SE_ROLE",
+        #          "warehouse": "SE_DEMO_WH",
+        #          "accountName": "thoughtspot_partner",
+        #          "user": "se_demo"
+        #       }
+        # '''
+        #
         post_data = {'connection_id': connection_guid,
                      'config': config_json_string,
                      'tables': json.dumps(tables),
@@ -1533,5 +1568,3 @@ class TSRestApiV1:
                           "externalDatabases": external_databases
                           }
         return final_response
-
-
